@@ -21,10 +21,6 @@ __author__ = 'Victor Olaya'
 __date__ = 'August 2012'
 __copyright__ = '(C) 2012, Victor Olaya'
 
-# This will get replaced with a git SHA1 when you do a git archive
-
-__revision__ = '93e761dd2396af21db9bb93e26d7cba680c906ca'
-
 import sys
 
 from qgis.core import (QgsRasterLayer,
@@ -62,10 +58,11 @@ from qgis.core import (QgsRasterLayer,
                        QgsProcessingParameterFeatureSource,
                        QgsProcessingParameterNumber)
 
-from PyQt5.QtCore import QCoreApplication
+from qgis.PyQt.QtCore import QCoreApplication
 
 PARAMETER_NUMBER = 'number'
 PARAMETER_DISTANCE = 'distance'
+PARAMETER_SCALE = 'scale'
 PARAMETER_RASTER = 'raster'
 PARAMETER_TABLE = 'vector'
 PARAMETER_VECTOR = 'source'
@@ -79,6 +76,7 @@ PARAMETER_POINT = 'point'
 PARAMETER_CRS = 'crs'
 PARAMETER_MULTIPLE = 'multilayer'
 PARAMETER_BAND = 'band'
+PARAMETER_LAYOUTITEM = 'layoutitem'
 PARAMETER_MAP_LAYER = 'Map Layer'
 PARAMETER_RANGE = 'range'
 PARAMETER_ENUM = 'enum'
@@ -89,7 +87,7 @@ PARAMETER_FOLDER_DESTINATION = 'folderDestination'
 PARAMETER_RASTER_DESTINATION = 'rasterDestination'
 
 
-def getParameterFromString(s):
+def getParameterFromString(s, context):
     # Try the parameter definitions used in description files
     if '|' in s and (s.startswith("QgsProcessingParameter") or s.startswith("*QgsProcessingParameter") or s.startswith('Parameter') or s.startswith('*Parameter')):
         isAdvanced = False
@@ -244,6 +242,8 @@ def getParameterFromString(s):
             if isAdvanced:
                 param.setFlags(param.flags() | QgsProcessingParameterDefinition.FlagAdvanced)
 
+            param.setDescription(QCoreApplication.translate(context, param.description()))
+
             return param
         else:
             return None
